@@ -10,13 +10,11 @@ sub birthday     { Time::Piece->( '1992/08/07', '%Y/%m/%d' ) }
 sub age          {14}
 sub blood_type   {'O'}
 sub challenge {
-    qw(
-       輝く金の花、キュアブルーム!
-       きらめく銀の翼、キュアイーグレット!
-       ふたりはプリキュア! 
-       聖なる泉を汚す者よ!
-       アコギな真似はおやめなさい!
-    )
+    "\e[38;5;198m輝く金の花、キュアブルーム!\e[0m",
+    "\e[38;5;250mきらめく銀の翼、キュアイーグレット!\e[0m",
+    "\e[38;5;201mふたりはプリキュア!\e[0m",
+    "\e[38;5;250m聖なる泉を汚す者よ!\e[0m",
+    "\e[38;5;198mアコギな真似はおやめなさい!\e[0m",
 }
 
 before 'transform' => sub {
