@@ -1,6 +1,6 @@
 package Acme::PrettyCure::Girl::CureFlower;
 use utf8;
-use Moo;
+use Any::Moose;
 use Time::Piece;
 
 with 'Acme::PrettyCure::Girl::Role';
@@ -9,7 +9,6 @@ sub human_name   {'花咲薫子'}
 sub precure_name {'キュアフラワー'}
 sub age          { 67 }
 sub challenge { qw(聖なる光に輝く一輪の花、キュアフラワー！) }
-sub image_url { '' }
 
 before 'transform' => sub {
     my ($self,) = @_;
@@ -20,4 +19,8 @@ before 'transform' => sub {
     }
 };
 
+
+no Any::Moose;
+__PACKAGE__->meta->make_immutable;
+
 1;
