@@ -13,7 +13,8 @@ has janken_db => (
         [
             qw(0 0 チョキ パー グー チョキ チョキ グー チョキ パー グー パー
               チョキ グー パー グー パー チョキ チョキ パー グー パー チョキ
-              パー チョキ パー パー グー チョキ グー パー 0 グー パー)
+              パー チョキ パー パー グー チョキ グー パー 0 グー パー チョキ
+              グー)
         ];
     },
 );
