@@ -1,6 +1,6 @@
 package Acme::PrettyCure::Girl::Role::Futari;
 use utf8;
-use Moo::Role;
+use Any::Moose '::Role';
 
 around 'transform' => sub {
     my $transform = shift;
